@@ -19,30 +19,36 @@ Views for snapshot module.
 """
 
 import json
+import subprocess
 
 from django.contrib import messages
 from django.shortcuts import redirect
 from django.template.response import TemplateResponse
-from django.urls import reverse
+from django.urls import reverse, reverse_lazy
 from django.utils.translation import ugettext as _
+from django.utils.translation import ugettext_lazy
 
 from plinth import actions
 from plinth.errors import ActionError
 from plinth.modules import snapshot as snapshot_module
-from plinth.utils import yes_or_no
 
 from . import get_configuration
 from .forms import SnapshotForm
 
+subsubmenu = [{
+    'url': reverse_lazy('snapshot:index'),
+    'text': ugettext_lazy('Configure')
+}, {
+    'url': reverse_lazy('snapshot:manage'),
+    'text': ugettext_lazy('Manage Snapshots')
+}]
+
 
 def index(request):
     """Show snapshot list."""
     status = get_configuration()
     if request.method == 'POST':
         form = SnapshotForm(request.POST)
-        if 'create' in request.POST:
-            actions.superuser_run('snapshot', ['create'])
-            messages.success(request, _('Created snapshot.'))
         if 'update' in request.POST and form.is_valid():
             update_configuration(request, status, form.cleaned_data)
             status = get_configuration()
@@ -50,49 +56,63 @@ def index(request):
     else:
         form = SnapshotForm(initial=status)
 
+    return TemplateResponse(
+        request, 'snapshot.html', {
+            'title': snapshot_module.name,
+            'description': snapshot_module.description,
+            'subsubmenu': subsubmenu,
+            'form': form
+        })
+
+
+def manage(request):
+    """Show snapshot list."""
+    if request.method == 'POST':
+        if 'create' in request.POST:
+            actions.superuser_run('snapshot', ['create'])
+            messages.success(request, _('Created snapshot.'))
+
     output = actions.superuser_run('snapshot', ['list'])
     snapshots = json.loads(output)
     has_deletable_snapshots = any(
         [snapshot for snapshot in snapshots[1:] if not snapshot['is_default']])
 
     return TemplateResponse(
-        request, 'snapshot.html', {
-            'title': snapshot_module.name,
-            'description': snapshot_module.description,
+        request, 'snapshot_manage.html', {
             'snapshots': snapshots,
             'has_deletable_snapshots': has_deletable_snapshots,
-            'form': form
+            'subsubmenu': subsubmenu,
         })
 
 
 def update_configuration(request, old_status, new_status):
     """Update configuration of snapshots."""
 
-    def update_key_configuration(key, stamp, threshold):
+    def make_config(args):
+        key, stamp = args[0], args[1]
         if old_status[key] != new_status[key]:
-            actions.superuser_run(
-                'snapshot', ['configure', stamp.format(threshold)])
+            return stamp.format(new_status[key])
+        else:
+            return None
+
+    new_status['number_min_age'] = int(new_status['number_min_age']) * 86400
+
+    config = filter(None,
+                    map(make_config, [
+                        ('enable_timeline_snapshots', 'TIMELINE_CREATE={}'),
+                        ('hourly_limit', 'TIMELINE_LIMIT_HOURLY={}'),
+                        ('daily_limit', 'TIMELINE_LIMIT_DAILY={}'),
+                        ('weekly_limit', 'TIMELINE_LIMIT_WEEKLY={}'),
+                        ('monthly_limit', 'TIMELINE_LIMIT_MONTHLY={}'),
+                        ('yearly_limit', 'TIMELINE_LIMIT_YEARLY={}'),
+                        ('number_min_age', 'NUMBER_MIN_AGE={}'),
+                    ]))
+
+    command = ['snapper', 'set-config'] + list(config)
 
     try:
-        update_key_configuration(
-            'enable_timeline_snapshots', 'TIMELINE_CREATE={}',
-            yes_or_no(new_status['enable_timeline_snapshots']))
-        update_key_configuration('hourly_limit', 'TIMELINE_LIMIT_HOURLY={}',
-                                 new_status['hourly_limit'])
-        update_key_configuration('daily_limit', 'TIMELINE_LIMIT_DAILY={}',
-                                 new_status['daily_limit'])
-        update_key_configuration('weekly_limit', 'TIMELINE_LIMIT_WEEKLY={}',
-                                 new_status['weekly_limit'])
-        update_key_configuration('monthly_limit', 'TIMELINE_LIMIT_MONTHLY={}',
-                                 new_status['monthly_limit'])
-        update_key_configuration('yearly_limit', 'TIMELINE_LIMIT_YEARLY={}',
-                                 new_status['yearly_limit'])
-        update_key_configuration('number_min_age', 'NUMBER_MIN_AGE={}',
-                                 int(new_status['number_min_age']) * 86400)
+        subprocess.run(command, check=True)
 
-        actions.superuser_run('snapshot', ['configure', 'NUMBER_LIMIT=0'])
-        actions.superuser_run('snapshot',
-                              ['configure', 'NUMBER_LIMIT_IMPORTANT=4-10'])
         messages.success(request, _('Storage snapshots configuration updated'))
     except ActionError as exception:
         messages.error(request,
@@ -108,7 +128,7 @@ def delete(request, number):
         messages.success(
             request,
             _('Deleted snapshot #{number}.').format(number=number))
-        return redirect(reverse('snapshot:index'))
+        return redirect(reverse('snapshot:manage'))
 
     output = actions.superuser_run('snapshot', ['list'])
     snapshots = json.loads(output)
@@ -125,7 +145,7 @@ def delete_all(request):
     if request.method == 'POST':
         actions.superuser_run('snapshot', ['delete-all'])
         messages.success(request, _('Deleted all snapshots.'))
-        return redirect(reverse('snapshot:index'))
+        return redirect(reverse('snapshot:manage'))
 
     output = actions.superuser_run('snapshot', ['list'])
     snapshots = json.loads(output)
